#========================================================================================
# package      DE_EPAGES::Design::API::Attributes::System
# state        private
# base         DE_EPAGES::Object::API::BaseAttribute
# description  Attribute interface for System, implements the attributes
#               <ul>
#                   <li>NavBars - list of all navigation bars</li>
#                   <li>NavElements - list of all navigation elements</li>
#               </ul>
#========================================================================================
package DE_EPAGES::Design::API::Attributes::System;
use base qw( DE_EPAGES::Object::API::BaseAttribute );

use strict;
use feature 'switch';
use DE_EPAGES::Core::API::File qw (GetSubDirectories ExistsDirectory);
use DE_EPAGES::Design::API::Constants qw ( @KNOWN_ICONSETS_IN_DISPLAY_ORDER );

sub getAttributes {
    my $self = shift;
    my ($Object, $aNames) = @_;
    my $hInfo = {};
    foreach my $Name ( @$aNames ) {
        given($Name) {
            when( 'Fonts' ) {
                $hInfo->{$Name} = $Object->folder('Fonts')->children;
            }
            when( 'NavBars' ) {
                $hInfo->{$Name} = $Object->folder('NavBars')->children;
            }
            when( 'NavElements' ) {
                $hInfo->{$Name} = $Object->folder('NavElements')->children;
            }
            when( 'NavElementGroups' ) {
                $hInfo->{$Name} = $Object->folder('NavElementGroups')->children;
            }
            when( 'ContentElements' ) {
                $hInfo->{$Name} = $Object->folder('ContentElements')->children;
            }
            when( 'ContentElementGroups' ) {
                $hInfo->{$Name} = $Object->folder('ContentElementGroups')->children;
            }
            when( 'LayoutIconSets' ) {
                my $Directory = $Object->get('PublicStoreTypePath').'/SF/Icon';
                my $Subs = ExistsDirectory($Directory) ? GetSubDirectories($Directory) : [];
                my %ExistingIconSets = map { $_ => 1 } grep { $_ ne 'CVS' } map { s/^\Q$Directory\E\///; $_} @$Subs;

                my @SortedIconSets;
                foreach my $KnownIconSet (@KNOWN_ICONSETS_IN_DISPLAY_ORDER) {
                    if ($ExistingIconSets{$KnownIconSet}) {
                        push(@SortedIconSets, $KnownIconSet);
                        delete $ExistingIconSets{$KnownIconSet};
                    }
                }

                foreach my $UnknownIconSet (keys %ExistingIconSets) {
                    push(@SortedIconSets, $UnknownIconSet);
                }

                @SortedIconSets = map { {'Directory' => $_} } @SortedIconSets;
                $hInfo->{$Name} = \@SortedIconSets;
            }
            when( 'LayoutImageSets' ) {
                my $Directory = $Object->get('PublicStoreTypePath').'/SF/ImageSet';
                my $Subs = ExistsDirectory($Directory) ? GetSubDirectories($Directory) : [];
                my @Sets = map { {'Directory' => $_} } grep { $_ ne 'CVS' } map { s/^\Q$Directory\E\///; $_} @$Subs;
                $hInfo->{$Name} = \@Sets;
            }
            when( 'Styles' ) {
                my $Directory = $Object->get('PublicStoreTypePath').'/SF/Styles';
                my $Subs = ExistsDirectory($Directory) ? GetSubDirectories($Directory) : [];
                my @Sets = map { {
                    'Directory'      => $_,
                    'StyleDirectory' => $_,
                } } grep { $_ ne 'CVS' } map { s/^\Q$Directory\E\///; $_} @$Subs;
                foreach my $Style (@Sets) {
                    my $SubStyleDirectory = $Directory.'/'.$Style->{'Directory'} .'/SubStyles';
                    my $SubSets = ExistsDirectory($SubStyleDirectory) ? GetSubDirectories($SubStyleDirectory) : [];
                    my @SubSets = map { {
                        'Directory'      => $_,
                        'StyleDirectory' => $Style->{'Directory'}.'/SubStyles/'.$_
                    } } grep { $_ ne 'CVS' } map { s/^\Q$SubStyleDirectory\E\///; $_} @$SubSets;
                    $Style->{'SubStyles'} = \@SubSets;
                }
                $hInfo->{$Name} = \@Sets;
            }
            when( 'StyleGroups' ) {
                $hInfo->{$Name} = $Object->folder('StyleGroups')->children;
            }
        }
    }
    return $hInfo;
}

1;
