#==============================================================================
# package      DE_EPAGES::Design::API::Constants
# state        private
#==============================================================================
package DE_EPAGES::Design::API::Constants;
use base Exporter;

use strict;
use Readonly;

our @EXPORT_OK = qw(
    CUSTOMIZABLE_BUTTONS
    @KNOWN_ICONSETS_IN_DISPLAY_ORDER
    NORMAL_FONTSTYLE
    REGULAR_FONTSTYLE
    ITALIC_FONTSTYLE
    DEFAULT_FONTWEIGHT
    @FONT_FILE_EXTENSIONS
);


#========================================================================================
# global       CUSTOMIZABLE_BUTTONS | hash of the attribute json structure
#                                       for the customizable buttons.
#                       | hash.ref of attribute names
#========================================================================================
use constant CUSTOMIZABLE_BUTTONS => {
    'Font' => [
        {'Name' => 'Color', 'Type'=>'string','Mandatory' => 1},
        {'Name' => 'Size', 'Type' => 'integer', 'Mandatory' => 1, 'MinValue' => 10, 'MaxValue' => 20}
    ],
    'Border' => [
        {'Name' => 'Color', 'Type' => 'string','Mandatory' => 1},
        {'Name' => 'Radius', 'Type' => 'integer', 'Mandatory' => 1,'MinValue' => 0, 'MaxValue' => 40}
    ],
    'Gradient' => [
        {'Name' => 'Color1', 'Type' => 'string','Mandatory' => 1},
        {'Name' => 'Color2', 'Type' => 'string','Mandatory' => 1}
    ],
    'Padding' => [
        {'Name' => 'Width', 'Type' => 'integer', 'Mandatory' => 1, 'MinValue' => 5, 'MaxValue' => 25},
        {'Name' => 'Height', 'Type' => 'integer', 'Mandatory' => 1,'MinValue' => 0, 'MaxValue' => 20}
    ]
};

Readonly our @KNOWN_ICONSETS_IN_DISPLAY_ORDER => qw(
    WireframeBlack
    WireframeWhite
    VistaIcons
    OrangeGlossy
    BusinessSymbols
    Christmas
    SimpleSymbols
    SimpleSymbolsAlt
    PixelDark
    PixelBlack
    PixelMix
    PixelWhite
);

#========================================================================================
# global       NORMAL_FONTSTYLE | normal font style | string
# global       REGULAR_FONTSTYLE | regular font style | string
# global       ITALIC_FONTSTYLE | italic font style | string
# global       DEFAULT_FONTWEIGHT | default font weight | string
# global       @FONT_FILE_EXTENSIONS | font file extensions | array
#========================================================================================
use constant NORMAL_FONTSTYLE   => 'normal';
use constant REGULAR_FONTSTYLE  => 'regular';
use constant ITALIC_FONTSTYLE   => 'italic';
use constant DEFAULT_FONTWEIGHT => '400';
Readonly our @FONT_FILE_EXTENSIONS => ('eot', 'woff2', 'woff', 'ttf', 'svg');


1;
