﻿#========================================================================================
# §package      DE_EPAGES::Design::API::Object::FontStyle
# §state        public
# §base         DE_EPAGES::Object::API::Object::Object
# §description  object interface for FontStyle.
#========================================================================================
package DE_EPAGES::Design::API::Object::FontStyle;
use base DE_EPAGES::Object::API::Object::Object;

use strict;
use utf8;

#========================================================================================
# §function     className
# §state        public
#----------------------------------------------------------------------------------------
# §syntax       $ClassName = $Style->className;
#----------------------------------------------------------------------------------------
# §description  Returns the class name, used for DAL access.
#----------------------------------------------------------------------------------------
# §return       $ClassName | class name | String
#========================================================================================
sub className  { 'FontStyle' }

#========================================================================================
# §function     filePath
# §state        public
#----------------------------------------------------------------------------------------
# §syntax       $Path = $Style->filePath;
#----------------------------------------------------------------------------------------
# §description  Constructs the file path of the locally stored Google Webfonts out of
#               the attributes of the font and the font style,
#               e.g. 'Fonts/expletus-sans-v10-latin/expletus-sans-v10-latin-italic'
#----------------------------------------------------------------------------------------
# §return       $Path | relative file path | string
#========================================================================================
sub filePath {
    my $self = shift;
    my $Font = $self->parent->parent;
    my $hInfoFont = $Font->get(['Version', 'EncodingString']);
    my $FontFolder = $Font->alias . '-v' . $hInfoFont->{'Version'} . '-' . $hInfoFont->{'EncodingString'};

    return 'Fonts/' . $FontFolder . '/' . $FontFolder . '-' . $self->alias;
}

1;
