#========================================================================================
# package      DE_EPAGES::Design::t::FontHandler
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for the TLE functions of the package
#               DE_EPAGES::Design::API::TLE::FontHandler
#========================================================================================
package DE_EPAGES::Design::t::FontHandler;

use base DE_EPAGES::Core::API::Test;
use DE_EPAGES::Cartridge::API::NonPermTemplate qw ( ProcessFileTemplate );
use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::Database::API::Connection qw ( GetTestSite RunOnStore );
use DE_EPAGES::Design::API::TLE::FontHandler;
use DE_EPAGES::TLE::API::BaseProcessor;
use Test::More;
use Test::Snapshot;
use strict;

use constant TEMPLATE_PATH => $ENV{EPAGES_CARTRIDGES} . '/DE_EPAGES/Design/Templates/BasePageType.SNIPPET-Google-Webfont.css';
our $Processor = DE_EPAGES::TLE::API::BaseProcessor->new;
our $FontHandler = DE_EPAGES::Design::API::TLE::FontHandler->new();
$FontHandler->register($Processor);


sub test {
    _test_GetGoogleWebFont();

    done_testing();
}

sub _test_GetGoogleWebFont {

    is_deeply_snapshot _GetGoogleWebFont('Anton'), 'Get Google Webfont \"Anton\" with base style.';
    is_deeply_snapshot _GetGoogleWebFont('Aton'), 'Try to get non existing Google Webfont \"Aton\". --> return empty';
    is_deeply_snapshot _GetGoogleWebFont('Anton:400,700,400italic,700italic'), 'Try to get Google Webfont \"Anton\" with many styles --> returns only one.';
    is_deeply_snapshot _GetGoogleWebFont('Expletus+Sans:400,700,400italic,700italic'), 'Get Google Webfont \"Expletus Sans\" with all styles.';
    is_deeply_snapshot _GetGoogleWebFont('Expletus+Sans:400i,700i'), 'Get Google Webfont \"Expletus Sans\" with italic styles and \"i\" instead of \"italic\".';
    is_deeply_snapshot _GetGoogleWebFont('Expletus+Sans:italic'), 'Get Google Webfont \"Expletus Sans\" italic styles with base weight.';
    is_deeply_snapshot _GetGoogleWebFont('Nothing+You+Could+Do:400:latin'), 'Get Google Webfont \"Nothing You Could Do\" with base style.';
}

sub _GetGoogleWebFont {
    my ($Webfont) = @_;
    return ProcessFileTemplate(TEMPLATE_PATH, {'SNIPPET' => {'Webfont' => $Webfont}}, $Processor);
}

RunScript( Message => 'long', Sub=> sub {
    RunOnStore( Store => GetTestSite(), Sub => \&test );
});

1;
